pub struct Variable(/* private fields */);Expand description
A value from the set $\small \mathcal{V}$.
A variable must start with a Unicode upper case letter, followed by any Unicode cased letter or
Unicode decimal digit, or the '_' underscore character.
Implementations